@@ -121,8 +121,9 @@ def get_indiv_memberships_choices(corp_membership):
     im_list = []
     indiv_memberships = MembershipDefault.objects.filter(
                             corp_profile_id=corp_membership.corp_profile.id,
-                            status_detail__in=['active', 'expired'],
-                            status=True)
+                            status=True).exclude(
+                            status_detail='archive'
+                                )
 
     for membership in indiv_memberships:
         indiv_memb_display = '<a href="%s" target="_blank">%s</a>' % (
@@ -221,9 +222,16 @@ def corp_memb_inv_add(user, corp_memb, **kwargs):
         inv.status_detail = 'estimate'
         inv.save(user)
 
+        if not corp_memb.payment_method:
+            is_online = True
+            if inv.balance <= 0:
+                is_online = False
+            corp_memb.payment_method = corp_memb.get_payment_method(
+                                            is_online=is_online)
+
         if user.profile.is_superuser:
             # if offline payment method
-            if not corp_memb.get_payment_method().is_online:
+            if not corp_memb.payment_method.is_online:
                 inv.tender(user)  # tendered the invoice for admin if offline
 
                 # mark payment as made
