@@ -555,7 +555,8 @@ def email_admins(event, total_amount, self_reg8n, reg8n, registrants):
     site_label = get_setting('site', 'global', 'sitedisplayname')
     site_url = get_setting('site', 'global', 'siteurl')
     admins = get_setting('module', 'events', 'admin_emails').split(',')
-    email_list = [admin.strip() for admin in admins]
+    notice_recipients = get_setting('site', 'global', 'allnoticerecipients').split(',')
+    email_list = [admin.strip() for admin in admins] + [recipient.strip() for recipient in notice_recipients]
     notification.send_emails(
         email_list,
         'event_registration_confirmation',
