@@ -1,13 +1,10 @@
 import math
-import os
-import csv
 import hashlib
 from hashlib import md5
-from datetime import datetime, timedelta, date, time
+from datetime import datetime, timedelta
 import time as ttime
 import subprocess
 from sets import Set
-import chardet
 import calendar
 
 from django.conf import settings
@@ -49,11 +46,11 @@ from tendenci.addons.corporate_memberships.models import (CorpMembership,
 from reports import ReportNewMems
 from tendenci.core.files.models import File
 from tendenci.core.exports.utils import render_csv, run_export_task
+from tendenci.core.perms.utils import get_notice_recipients
 
 from tendenci.apps.profiles.models import Profile
 from tendenci.addons.memberships.models import (App, AppEntry, Membership,
     MembershipType, Notice, MembershipImport, MembershipDefault,
-    MembershipDemographic,
     MembershipImportData, MembershipApp)
 from tendenci.addons.memberships.forms import (MembershipExportForm,
     AppCorpPreForm, MembershipForm, MembershipDefaultForm,
@@ -66,7 +63,6 @@ from tendenci.addons.memberships.utils import (is_import_valid, prepare_chart_da
     get_membership_stats, NoMembershipTypes, ImportMembDefault)
 from tendenci.addons.memberships.importer.forms import ImportMapForm, UploadForm
 from tendenci.addons.memberships.importer.utils import parse_mems_from_csv
-from tendenci.addons.memberships.utils import membership_rows, memb_import_parse_csv
 from tendenci.addons.memberships.importer.tasks import ImportMembershipsTask
 from tendenci.core.base.forms import CaptchaForm
 
@@ -537,7 +533,6 @@ def application_confirmation_default(request, hash):
     template_name = 'memberships/applications/confirmation_default2.html'
     membership = get_object_or_404(MembershipDefault, guid=hash)
     if membership.corporate_membership_id:
-        from tendenci.addons.corporate_memberships.models import CorpMembershipApp
         corp_app = CorpMembershipApp.objects.current_app()
         if not corp_app:
             raise Http404
@@ -819,8 +814,7 @@ def membership_import_upload(request, template_name='memberships/import-upload-f
             csv.is_public = False
             csv.save()
 
-            file_path = str(csv.file.name)
-            #file_path = os.path.join(settings.MEDIA_ROOT, csv.file.name)
+            file_path = unicode(csv.file.name)
 
             import_valid, import_errs = is_import_valid(file_path)
 
@@ -860,7 +854,6 @@ def membership_import_preview(request, id):
             #show the user a preview based on the mapping
             cleaned_data = form.cleaned_data
             file_path = memport.get_file().file.name
-            #file_path = os.path.join(settings.MEDIA_ROOT, memport.get_file().file.name)
             memberships, stats = parse_mems_from_csv(
                 file_path,
                 cleaned_data,
@@ -1014,22 +1007,24 @@ def membership_default_import_preview(request, mimport_id,
     """
     Preview the import
     """
+
     if not request.user.profile.is_superuser:
         raise Http403
+
     invalidate('memberships_membershipimport')
-    mimport = get_object_or_404(MembershipImport,
-                                    pk=mimport_id)
+    mimport = get_object_or_404(MembershipImport, pk=mimport_id)
 
     if mimport.status == 'preprocess_done':
-#        fieldnames, data_list = memb_import_parse_csv(mimport)
+
         try:
             curr_page = int(request.GET.get('page', 1))
         except:
             curr_page = 1
+
         num_items_per_page = 10
-#        total_rows = len(data_list)
-        total_rows = MembershipImportData.objects.filter(
-                                mimport=mimport).count()
+
+        total_rows = MembershipImportData.objects.filter(mimport=mimport).count()
+
         # if total_rows not updated, update it
         if mimport.total_rows != total_rows:
             mimport.total_rows = total_rows
@@ -1408,7 +1403,6 @@ def membership_default_add(request,
     corp_membership = None
 
     if join_under_corporate:
-        from tendenci.addons.corporate_memberships.models import CorpMembershipApp
         corp_app = CorpMembershipApp.objects.current_app()
         if not corp_app:
             raise Http404
@@ -1612,6 +1606,18 @@ def membership_default_add(request,
                     args=[membership.pk],
                 ))
 
+            # send email notification to admin
+            recipients = get_notice_recipients(
+                                       'module', 'memberships',
+                                       'membershiprecipients')
+            extra_context = {
+                'membership': membership,
+                'app': app,
+                'request': request
+            }
+            send_email_notification('membership_joined_to_admin', recipients,
+                                    extra_context)
+
             # redirect: confirmation page
             return HttpResponseRedirect(reverse(
                 'membership.application_confirmation_default',
@@ -1811,6 +1817,7 @@ def membership_join_report(request):
                 },
                 context_instance=RequestContext(request))
 
+
 @staff_member_required
 @password_required
 def membership_export(request):
@@ -1853,15 +1860,17 @@ def membership_join_report_pdf(request):
 
     return resp
 
+
 @staff_member_required
 def report_list(request, template_name='reports/membership_report_list.html'):
     """ List of all available membership reports.
     """
-    
+
     EventLog.objects.log()
-    
+
     return render_to_response(template_name, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_active_members(request, template_name='reports/membership_list.html'):
     if request.GET.get('days'):
@@ -2149,22 +2158,24 @@ def report_members_stats(request, template_name='reports/membership_stats.html')
         'total': total,
         }, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_member_roster(request, template_name='reports/membership_roster.html'):
     """ Shows membership roster. Extends base-print for easy printing.
     """
     members = MembershipDefault.objects.filter(status=1, status_detail="active").order_by('user__last_name')
-    
+
     EventLog.objects.log()
 
     return render_to_response(template_name, {'members': members}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_member_quick_list(request, template_name='reports/membership_quick_list.html'):
     """ Table view of current members fname, lname and company only.
     """
     members = MembershipDefault.objects.filter(status=1, status_detail="active").order_by('user__last_name')
-    
+
     # returns csv response ---------------
     ouput = request.GET.get('output', '')
     if ouput == 'csv':
@@ -2195,19 +2206,20 @@ def report_member_quick_list(request, template_name='reports/membership_quick_li
 
     return render_to_response(template_name, {'members': members}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_members_by_company(request, template_name='reports/members_by_company.html'):
     """ Total current members by company.
     """
     active_mems = MembershipDefault.objects.filter(status=1, status_detail="active")
     company_list = []
-    
+
     # get list of distinct companies
     for member in active_mems:
         if member.user.profile.company:
             if member.user.profile.company not in company_list:
                 company_list.append(member.user.profile.company)
-    
+
     # get total number of active members for each company
     companies = []
     for company in company_list:
@@ -2217,13 +2229,14 @@ def report_members_by_company(request, template_name='reports/members_by_company
             'total_members': total_members
         }
         companies.append(company_dict)
-    
+
     companies = sorted(companies, key=lambda k: k['total_members'], reverse=True)
-    
+
     EventLog.objects.log()
 
     return render_to_response(template_name, {'companies': companies}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_renewed_members(request, template_name='reports/renewed_members.html'):
     """ Table of memberships ordered by renew dt, filterable by time period between renew date and now.
@@ -2234,11 +2247,11 @@ def report_renewed_members(request, template_name='reports/renewed_members.html'
         days = 30
     compare_dt = datetime.now() - timedelta(days=days)
     members = MembershipDefault.objects.filter(renewal=1, renew_dt__gte=compare_dt).order_by('renew_dt')
-    
+
     # returns csv response ---------------
     ouput = request.GET.get('output', '')
     if ouput == 'csv':
-    
+
         table_header = [
             'member number',
             'last name',
@@ -2249,10 +2262,10 @@ def report_renewed_members(request, template_name='reports/renewed_members.html'
             'country',
             'renew date'
         ]
-    
+
         table_data = []
         for mem in members:
-    
+
             table_data.append([
                 mem.member_number,
                 mem.user.last_name,
@@ -2263,7 +2276,7 @@ def report_renewed_members(request, template_name='reports/renewed_members.html'
                 mem.user.profile.country,
                 mem.renew_dt
             ])
-    
+
         return render_csv(
             'renewed-members.csv',
             table_header,
@@ -2275,6 +2288,7 @@ def report_renewed_members(request, template_name='reports/renewed_members.html'
 
     return render_to_response(template_name, {'members': members, 'days': days}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_renewal_period_members(request, template_name='reports/renewal_period_members.html'):
     """ Table of memberships ordered by join dt, filterable by time period between join date and now.
@@ -2300,6 +2314,7 @@ def report_renewal_period_members(request, template_name='reports/renewal_period
 
     return render_to_response(template_name, {'members': members}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_grace_period_members(request, template_name='reports/grace_period_members.html'):
     """ List of memberships that are past expiration date but status detail still = active.
@@ -2325,16 +2340,16 @@ def report_grace_period_members(request, template_name='reports/grace_period_mem
 
     return render_to_response(template_name, {'members': members}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_active_members_ytd(request, template_name='reports/active_members_ytd.html'):
     import datetime
-    from datetime import timedelta
-    
+
     year = datetime.datetime.now().year
-    years = [year, year-1, year-2, year-3, year-4]
+    years = [year, year - 1, year - 2, year - 3, year - 4]
     if request.GET.get('year'):
         year = int(request.GET.get('year'))
-    
+
     active_mems = MembershipDefault.objects.filter(status=True, status_detail="active")
 
     total_new = active_mems.filter(join_dt__year=year).count()
@@ -2352,7 +2367,7 @@ def report_active_members_ytd(request, template_name='reports/active_members_ytd
         if index is 12:
             date = datetime.date(year, 12, 31)
         else:
-            date = datetime.date(year, index+1, 1) - datetime.timedelta(days=1)
+            date = datetime.date(year, index + 1, 1) - datetime.timedelta(days=1)
         total_active = MembershipDefault.objects.filter(
             create_dt__lte=date,
             expire_dt__gt=date,
@@ -2367,16 +2382,16 @@ def report_active_members_ytd(request, template_name='reports/active_members_ytd
         months.append(month_dict)
 
     EventLog.objects.log()
-    
+
     return render_to_response(template_name, {'months': months, 'total_new': total_new, 'total_renew': total_renew, 'years': years, 'year': year}, context_instance=RequestContext(request))
 
+
 @staff_member_required
 def report_members_ytd_type(request, template_name='reports/members_ytd_type.html'):
     import datetime
-    from datetime import timedelta
-    
+
     year = datetime.datetime.now().year
-    years = [year, year-1, year-2, year-3, year-4]
+    years = [year, year - 1, year - 2, year - 3, year - 4]
     if request.GET.get('year'):
         year = int(request.GET.get('year'))
 
@@ -2409,7 +2424,7 @@ def report_members_ytd_type(request, template_name='reports/members_ytd_type.htm
                 'expired_mems': expired_mems,
             }
             types_expired.append(expired_dict)
-    
+
     totals_new = []
     totals_renew = []
     totals_expired = []
@@ -2423,8 +2438,7 @@ def report_members_ytd_type(request, template_name='reports/members_ytd_type.htm
         totals_new.append(new)
         totals_renew.append(renew)
         totals_expired.append(expired)
-        
 
     EventLog.objects.log()
-    
+
     return render_to_response(template_name, {'months': months, 'years': years, 'year': year, 'types_new': types_new, 'types_renew': types_renew, 'types_expired': types_expired, 'totals_new': totals_new, 'totals_renew': totals_renew, 'totals_expired': totals_expired}, context_instance=RequestContext(request))
